OiRA

Help

1. Voorbereiding
3. Inventarisatie + Evaluatie
4. Plan van aanpak
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Risico aanwezig
5. Rapport
6. Status 9%

# Commercial guarding, Leicester

Door het invullen van de vragenlijst heeft u een Risico-inventarisatie gemaakt. Op basis hiervan stelt u een Plan van aanpak op. Dit Plan van aanpak moet jaarlijks op voortgang worden besproken en daar moet een rapportje over worden geschreven. Er zijn onderwerpen afgehandeld en misschien komen er nieuwe onderwerpen bij. Betrek bij bespreking over de voortgang ook de eventuele oorzaken van ongevallen en de eventuele oorzaken van verzuim. Misschien wilt u deze oorzaken voorrang geven en zijn ze van invloed op de onderwerpen die u het komende jaar gaat aanpakken. Het is handig om de opstelling van een Plan van aanpak of de bespreking over voortgang samen te laten lopen met het opstellen van de jaarlijkse begroting. Door onderwerpen uit het Plan van aanpak met investeringen te laten samen vallen kunnen deze vaak zonder extra geld worden opgelost.

In het plan van aanpak geeft u aan welke maatregelen genomen gaan worden om het risico op te lossen. Het wegnemen van de oorzaak (aanpak bij de bron) heeft de voorkeur: op die manier kan het risico worden voorkomen. Bij de maatregel geeft u aan welke stappen genomen moeten worden om het risico te voorkomen of te verminderen. Ook de kennis en ervaring die nodig zijn om dit uit te voeren, vult u in (preventieplan en vereisten).

1. Kan het risico worden vermeden? Denk hierbij bijvoorbeeld aan:
   - Het afschaffen van de taak of het werk waar het risico speelt
   - Het vermijden van het risico zelf
2. Als het risico toch niet te vermijden is, bekijk dan of het risico niveau waaraan de werknemer wordt blootgesteld verlaagd kan worden.

Als u besloten heeft hoe het risico aan te pakken, beschrijft u wat u hier voor gaat doen. Daarbij beschrijft u ook wat er voor nodig is. Zowel ik kennis/expertise als in materialen en eventuele andere vereisten.

Begin plan van aanpak

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More